Coverage for src/configuraptor/__init__.py: 100%

1"""

2 Exposes TypedConfig and load_into for this library.

3"""

4

5# SPDX-FileCopyrightText: 2023-present Robin van der Noord <robinvandernoord@gmail.com>

6#

7# SPDX-License-Identifier: MIT

8 from .cls import TypedConfig

9 from .core import (

10 all_annotations,

11 check_and_convert_data,

12 convert_config,

13 ensure_types,

14 load_into,

15 load_into_class,

16 load_into_instance,

17)

18 from .dump import asdict, asjson, astoml, asyaml

19 from .postpone import postpone

20 from .singleton import Singleton, SingletonMeta

21

22 __all__ = [

23 # cls

24 "TypedConfig",

25 # singleton

26 "Singleton",

27 "SingletonMeta",

28 # core

29 "all_annotations",

30 "check_and_convert_data",

31 "convert_config",

32 "ensure_types",

33 "load_into",

34 "load_into_class",

35 "load_into_instance",

36 # postpone

37 "postpone",

38 # dump

39 "asdict",

40 "astoml",

41 "asyaml",

42 "asjson",

43]